@@ -9,17 +9,8 @@ function(cop=NULL, v, t,
             return(LHS - dc)
             }
     my.rt <- NULL
-    try(my.rt <- uniroot(func,interval=c(0,1),
-                         v=v, LHS=t, cop=cop,
-                         delv=delv, para=para, ...))
-    
-    if(is.null(my.rt)) return(NA);
-
-    if(length(my.rt$root) != 0) {
-      u <- my.rt$root
-      return(u)
-    }
-    else {
-      return(NA)
-    }
+    try(my.rt <- uniroot(func,interval=c(0,1), v=v, LHS=t,
+                              cop=cop, delv=delv, para=para, ...))
+    if(is.null(my.rt)) return(NA) # Now the returned root is "u"
+    ifelse(length(my.rt$root) != 0, return(my.rt$root), return(NA))
 }
